@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2012 by Barry A. Warsaw
+# Copyright (C) 1998-2013 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -78,7 +78,7 @@ PATTERNS = [
     # sz-sb.de, corridor.com, nfg.nl
     (_c('the following addresses had'),
      _c('transcript of session follows'),
-     _c(r'<(?P<fulladdr>[^>]*)>|\(expanded from: <?(?P<addr>[^>)]*)>?\)')),
+     _c(r'^ *(\(expanded from: )?<?(?P<addr>[^\s@]+@[^\s@>]+?)>?\)?\s*$')),
     # robanal.demon.co.uk
     (_c('this message was created automatically by mail delivery software'),
      _c('original message follows'),
@@ -220,6 +220,15 @@ PATTERNS = [
     (_c('Message not delivered to the following addresses'),
      _c('Error detail'),
      _c('\s*(?P<addr>[^\s@]+@[^\s@)]+)')),
+    # Dovecot LDA Over quota MDN (bogus - should be DSN).
+    (_c('^Your message'),
+     _c('^Reporting'),
+     _c('Your message to <?(?P<addr>[^\s<@]+@[^\s@>]+)>? was automatically'
+        ' rejected')),
+    # mail.ru
+    (_c('A message that you sent was rejected'),
+     _c('This is a copy of your message'),
+     _c('\s(?P<addr>[^\s@]+@[^\s@]+)')),
     # Next one goes here...
     ]
 
