@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2012 by Barry A. Warsaw
+# Copyright (C) 2011-2013 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -115,7 +115,8 @@ DATA = (
     # Exim bounces
     ('exim', 'exim_01.txt', [b'delangen@its.tudelft.nl']),
     # SimpleMatch bounces
-    ('simplematch', 'sendmail_01.txt', [b'zzzzz@nfg.nl']),
+    ('simplematch', 'sendmail_01.txt', [b'zzzzz@shaft.coal.nl',
+                                        b'zzzzz@nfg.nl']),
     ('simplematch', 'simple_01.txt', [b'bbbsss@turbosport.com']),
     ('simplematch', 'simple_02.txt', [b'chris.ggggmmmm@usa.net']),
     ('simplematch', 'simple_04.txt', [b'claird@starbase.neosoft.com']),
@@ -152,6 +153,8 @@ DATA = (
     ('simplematch', 'simple_34.txt', [b'roland@xxx.com']),
     ('simplematch', 'simple_36.txt', [b'garyt@xxx.com']),
     ('simplematch', 'simple_37.txt', [b'user@uci.edu']),
+    ('simplematch', 'simple_38.txt', [b'prueba@domain.com']),
+    ('simplematch', 'simple_39.txt', [b'foo@mail.ru']),
     ('simplematch', 'bounce_02.txt', [b'acinsp1@midsouth.rr.com']),
     ('simplematch', 'bounce_03.txt', [b'james@jeborall.demon.co.uk']),
     # SimpleWarning
@@ -210,6 +213,7 @@ DATA = (
     ('qmail', 'qmail_05.txt', [b'ivokggrrdvc@caixaforte.freeservers.com']),
     ('qmail', 'qmail_06.txt', [b'ntl@xxx.com']),
     ('qmail', 'qmail_07.txt', [b'user@example.net']),
+    ('qmail', 'qmail_08.txt', []),
     # LLNL's custom Sendmail
     ('llnl', 'llnl_01.txt', [b'trotts1@llnl.gov']),
     # Netscape's server...
@@ -242,6 +246,7 @@ DATA = (
     ('yahoo', 'yahoo_10.txt', [b'jajcchoo@yahoo.com',
                                b'lyons94706@yahoo.com',
                                b'turtle4jne@yahoo.com']),
+    ('yahoo', 'yahoo_11.txt', [b'bad_user@aol.com']),
     # sina.com appears to use their own weird SINAEMAIL MTA
     ('sina', 'sina_01.txt', [b'boboman76@sina.com', 
                              b'alan_t18@sina.com']),
