@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2012 by Barry A. Warsaw
+# Copyright (C) 1998-2013 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -35,14 +35,21 @@ from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
 
 
-tcre = re.compile(r'message\s+from\s+yahoo\.\S+', re.IGNORECASE)
+tcre = (re.compile(r'message\s+from\s+yahoo\.\S+', re.IGNORECASE),
+        re.compile(r'Sorry, we were unable to deliver your message to '
+                   r'the following address(\(es\))?\.',
+                   re.IGNORECASE),
+        )
 acre = re.compile(r'<(?P<addr>[^>]*)>:')
-ecre = re.compile(r'--- Original message follows')
+ecre = (re.compile(r'--- Original message follows'),
+        re.compile(r'--- Below this line is a copy of the message'),
+        )
 
 
-class ParseState(Enum):
+class _ParseState(Enum):
     start = 0
     tag_seen = 1
+    all_done = 2
 
 
 
@@ -58,18 +65,25 @@ class Yahoo:
         if not sender.startswith('mailer-daemon@yahoo'):
             return NoFailures
         addresses = set()
-        state = ParseState.start
+        state = _ParseState.start
         for line in body_line_iterator(msg):
             line = line.strip()
-            if state is ParseState.start and tcre.match(line):
-                state = ParseState.tag_seen
-            elif state is ParseState.tag_seen:
+            if state is _ParseState.start:
+                for cre in tcre:
+                    if cre.match(line):
+                        state = _ParseState.tag_seen
+                        break
+            elif state is _ParseState.tag_seen:
                 mo = acre.match(line)
                 if mo:
                     addresses.add(mo.group('addr').encode('us-ascii'))
                     continue
-                mo = ecre.match(line)
-                if mo:
-                    # We're at the end of the error response.
+                for cre in ecre:
+                    mo = cre.match(line)
+                    if mo:
+                        # We're at the end of the error response.
+                        state = _ParseState.all_done
+                        break
+                if state is _ParseState.all_done:
                     break
         return NoTemporaryFailures, addresses
